@@ -383,7 +383,7 @@ impl Contest {
             } else {
                 parsed_pdf_path.push_str(&unparsed_pdf_path);
             }
-            let latexmk = Command::new("latexmk").args([&["-pdflatex=", &self.template.1.engine].concat(), "-pdf", "-f", tex_path]).output().expect("Failed to execute latexmk.\nMake sure you have the latexmk script installed\nand make sure it is in your PATH.");
+            let latexmk = Command::new("latexmk").args([&format!("-pdflatex=`{}`", &self.template.1.engine), "-pdf", "-f", tex_path]).output().expect("Failed to execute latexmk.\nMake sure you have the latexmk script installed\nand make sure it is in your PATH.");
             if latexmk.status.success() {
                 results.push(Ok(["Finished compiling ", &parsed_pdf_path].concat()));
                 let original_pdf_path = Path::new(tex_path).with_extension("pdf");
