@@ -24,7 +24,7 @@ pub type Solutions = Vec<HashMap<String, String>>;
 
 #[derive(Debug, Serialize, Deserialize)]
 struct SerializedProblem {
-    pub solutions: Solutions,
+    pub solutions: Option<Solutions>,
     #[serde(flatten)]
     pub vars: HashMap<String, Value>,
 }
@@ -206,17 +206,13 @@ impl Problem {
         for filter_action in filters {
             match filter_action {
                 Positive(filter) => {
-                    if self.try_filter(filter) {
-                        return Some(self);
-                    } else {
+                    if !self.try_filter(filter) {
                         return None;
                     }
                 }
                 Negative(filter) => {
                     if self.try_filter(filter) {
                         return None;
-                    } else {
-                        return Some(self);
                     }
                 }
             }
@@ -467,10 +463,12 @@ pub fn parse_problem_yaml(yaml: &str) -> MapmResult<Problem> {
                 }
             }
 
-            return Success(Problem {
-                vars,
-                solutions: problem.solutions,
-            });
+            let solutions: Solutions = match problem.solutions {
+                Some(solutions) => solutions,
+                None => Vec::new(),
+            };
+
+            return Success(Problem { vars, solutions });
         }
         Err(err) => {
             return Fail(ProblemErr(err.to_string()));
